
from twisted.trial import unittest
dr = unittest.deferredResult
from twisted.internet import defer

import petmail.crypto
petmail.crypto.EncryptionAgent = petmail.crypto.FakeEncryptionAgent

from petmail import agent, addressbook
from petmail.idrecord import IDRecord

class TestMixin:
    def setUp(self):
        self.agent = agent.Agent("test_lookup")
        self.agent.init()
        self.owners = []

        for i in range(3):
            me = dr(self.agent.createIdentity())
            me.setName("owner%d" % i)
            me.addAddress("addr%d@example.com" % i)
            self.owners.append(me)

    def test1(self):
        s = self.server()
        dr(self.owners[0].publish([s]))
        dr(self.owners[1].publish([s]))
        # but don't publish owners[2]

        r0 = self.owners[0]
        signed = dr(s.lookup(self.agent, "addr0@example.com"))
        self.failUnless(signed)
        self.failUnless(type(signed) == str)
        r = IDRecord()
        dr(r.createFromSigned(signed, self.agent.crypto))
        self.failUnlessEqual(r0.ID, r.ID)
        self.failUnlessEqual(r0.names, r.name)

        # this lookup should fail, either with a KeyError or by returning
        # None
        try:
            d = s.lookup(self.agent, "addr2@example.com")
            signed = dr(d)
            self.failUnless(signed is None)
        except KeyError:
            pass

class FakeServer(TestMixin, unittest.TestCase):
    def server(self):
        return addressbook.FakeNameServer()

class DiskServer(TestMixin, unittest.TestCase):
    def server(self):
        return addressbook.DiskNameServer("diskserver")

# TODO: PBNameServer
