#! /usr/bin/python

from distutils.core import setup
from distutils.command.install_data import install_data

long_description = """
PETMail is a new email transport intended to eliminate spam. All
messages are signed and encrypted. Recipients give explicit permission
to senders (by keyid), and only authorized senders are allowed
unlimited access to the recipient's inbox. New senders must pass a
CAPTCHA challenge or other rate-limiting test to be allowed to send a
single message. Permission is automatically extended in ways that
correspond to natural human communication patterns.
"""

# Make sure data files are installed. Without this, the data files get
# put in the wrong directory (/usr/petmail/gui/gui.glade instead of
# /usr/lib/python2.3/site-packages/petmail/gui/gui.glade). This is
# taken from twisted's setup.py, where it is labeled "this is evil".
class install_data_twisted(install_data):
    def finalize_options (self):
        self.set_undefined_options('install',
            ('install_lib', 'install_dir')
        )
        install_data.finalize_options(self)

setup(name="petmail",
      version="0.1.3",
      description = "PETMail consent-based email transport",
      long_description = long_description,
      author = "Brian Warner",
      author_email = "warner-newsmtp@lothar.com",
      url = "http://www.lothar.com/tech/spam/index.html",
      license = "GNU GPL",
      packages = ["petmail", "petmail/gui", "petmail/scripts",
                  "petmail/test"],
      data_files = [("petmail/gui", ["petmail/gui/gui.glade",
                                     "docs/sheep.gif"])],
      scripts = ["bin/petmail"],
      cmdclass = { 'install_data': install_data_twisted },
      )

#  keep the long_description narrow enough to fit something
# Local Variables:
# fill-column: 71
# End:
